extensions [queryonto array csv]
;; the queryonto extension was developed by the authors of this simulation
;; this extension use the JENA library to make queries over
;; the ontology of citizenship competences (also developed for this simulation)

breed [citizens allCitizens]

globals[
  ;; Color variables
  hsb-as-rgb
  hsb-color
  rgb-color

  zoneName ; Name of the escenario

  conflictsList ; list of conflicts, each conflict is also a list which includes: pcolor, escenarioName, competencesList

  turtlesToEvaluate ;; list of turtles to evaluate in each conflict (2 agents)

  solved
  notSolved

  ;; variables for conflicts styles
  avoiding competing accommodating collaborating compromising

  ;; Variables for conflicts solved
  confSolWork
  confSolHome
  confSolStreet
  confSolSocialM

  ;; Variables for the total number of interactions in a conflict
  totalConfSolWork
  totalConfSolHome
  totalConfSolStreet
  totalConfSolSocialM

  ;; Variable to store the global competence level
  competenceLevel ;; general level of competence, a mean of allLevels
  allLevels ;; list of all levels of competence that rise up

  ;; Variables to count the number of times people is present in a zone
  peopleAtWork
  peopleAtHome
  peopleAtStreet
  peopleAtSocialMarketing

  ;; List for CSV data
  csvData
  countRowsCsv

]

turtles-own[
  individualCompetences
]
to setup
  clear-all
  reset-ticks

  createCitizens

  set csvData []

  ask turtle 0
  [ setZoneName ]

  set hsb-as-rgb hsb 180 100 100
  ask quadrant -1 1 [ set pcolor  green] ;; Work zone
  ask quadrant -1 -1 [ set pcolor  magenta] ;; Home zone
  ask quadrant 1 1 [ set pcolor  violet] ;; SocialMarketing zone
  ask quadrant 1 -1 [ set pcolor  cyan] ;; Street zone

  ;; Setting atmost 10 conflicts per zone
  set-conflicts "Work"
  set-conflicts "Home"
  set-conflicts "Street"
  set-conflicts "SocialMarketing"

  display
end

to restart
  ask turtles [die]
  clear-all
  reset-ticks
  set withCompetences false
  set numberOfCitizens 10
end

;; numberOfCitizens citizens are created in the simulation environment
to createCitizens
  create-citizens numberOfCitizens
  [
    set color 69
    set shape "person"
    setxy random-xcor random-ycor
    ;set label who
  ]
end

;; asigning a  zoneName to each quadrant
to setZoneName
  if(patch-quadrant = list 1 1) [ set zoneName "SocialMarketing" ]
  if(patch-quadrant = list 1 -1) [ set zoneName "Street" ]
  if(patch-quadrant = list -1 -1) [ set zoneName "Home" ]
  if(patch-quadrant = list -1 1) [ set zoneName "Work" ]
end

;; retrieven patches in a specific quadrant
to-report quadrant [x y]  ;; inputs are 1 or -1
  report patches with [patch-quadrant = list x y]
end

;; At most 10 conflicts are setted to the environment
;; A conflict is represented by a set of 9 patches
;; Each conflict has its own color
to set-conflicts [place]
  ;; The value of these variables is varies according to each escenario
  let colorC 0 let xmin 0   let xmax 0 let ymin 0 let ymax 0

  ;; Escenario: Work
  if (place = "Work") [ set colorC 42 set xmin 0 set xmax 20 set ymin 20 set ymax 40 ]
  ;; Escenario: Home
  if (place = "Home") [ set colorC 132 set xmin 0 set xmax 20 set ymin 0 set ymax 20 ]
  ;; Escenario: Street
  if (place = "Street") [ set colorC 102 set xmin 20 set xmax 40 set ymin 0 set ymax 20 ]
  ;; Escenario: Social Marketing
  if (place = "SocialMarketing") [ set colorC 2 set xmin 20 set xmax 40 set ymin 20 set ymax 40 ]

  repeat 10 [
    let newX (xmax) + random ((xmin) - (xmax))
    let newY (ymax) + random ((ymin) - (ymax))
    create-turtles 1 [
      setxy newX newY
      let currentColor pcolor
      let dieturtle false
      ask neighbors [
        if (pcolor != currentColor) [ set dieturtle true ]
      ]
      if (dieturtle = false) [
        set pcolor colorC
        paint-patches neighbors colorC place
        set colorC colorC + 0.5
      ]
      die
    ]
  ]
end

;;retrieving an specific quadrant
to-report patch-quadrant  ;; patch procedure
  report list ifelse-value (pxcor < world-width / 2) [-1] [1]
              ifelse-value (pycor < world-width / 2) [-1] [1]
end

;; All patches in the patchesSet will be coloured with newColor
to paint-patches [patchesSet newColor zone]
  let countPatches 0
  ask patchesSet [
    set pcolor newColor
    if (countPatches = 0) [
      add-conflict-to-list newColor zone
    ]
    set countPatches countPatches + 1
  ]
end

;; A new conflict is added to the conflictsList
;; The conflictsList will allow to add the competences of each conflict
to add-conflict-to-list [color_p zone]

  if (conflictsList = 0 ) [
    set conflictsList []
  ]

  let competences array:from-list queryonto:ontology zone conflictsList


  let conflictName array:item competences 0
  let competence item 0 item 0 array:item competences 1
  let eachConflict []
  if (conflictName != "empty") [
      set eachConflict lput conflictName eachConflict ;; eachConflict[0]
      set eachConflict lput zone eachConflict ;; eachConflict[1]
      set eachConflict lput color_p eachConflict ;; eachConflict[2]
      set eachConflict lput competence eachConflict ;; eachConflict[3]
      set conflictsList lput eachConflict conflictsList ;; Adding the eachConflict to the conflictsList
  ]
end

to go

  tick

  ;; Mooving agents randomly
  ask citizens [
    right random 360
    forward 2
  ]

  let agentsToNotEvaluate []

  ;user-message (word "cantidad de agentes: " count citizens with [(pcolor >= 2 and pcolor < 10) or (pcolor >= 42 and pcolor < 50) or (pcolor >= 102 and pcolor < 110) or (pcolor >= 132 and pcolor < 140)])
  ask citizens with [(pcolor >= 2 and pcolor < 10) or (pcolor >= 42 and pcolor < 50) or (pcolor >= 102 and pcolor < 110) or (pcolor >= 132 and pcolor < 140)]
  [
    ;; setting the name of the zone in which the agent is present
    setZoneName

    let colorCurrentAgent pcolor

    if (existsConflict pcolor = true) [
      let counter count turtles with [pcolor = colorCurrentAgent]
      if (counter = 2) [
        let countTurtles 0
        ask turtles with [pcolor = colorCurrentAgent]
        [
          if (agentExists who = false) [
            if(turtlesToEvaluate = 0) [
              set turtlesToEvaluate []
            ]
            set turtlesToEvaluate lput who turtlesToEvaluate
            set-competence-agent who colorCurrentAgent
            set countTurtles countTurtles + 1
            if (countTurtles = 2) [
              set turtlesToEvaluate lput colorCurrentAgent turtlesToEvaluate
              ;user-message agentsToEvaluate
            ]
          ]
          set agentsToNotEvaluate lput who agentsToNotEvaluate
        ]
      ]
    ]

    file-open "competences.csv"
    file-print csv:to-row (list who individualCompetences)
    file-close

  ];; closes ask citizens
  ;
  ifelse (turtlesToEvaluate != 0 )[

    evaluate-agents turtlesToEvaluate
  ][
    set csvData lput countRowsCsv csvData; Row Number (name in R)
    set csvData lput ticksNumber csvData ; ticks number
    set csvData lput ticks csvData ; current tick
    set csvData lput -1 csvData ; zone
    set csvData lput -1 csvData ; agent 1
    set csvData lput -1 csvData ; agent 2
    set csvData lput -1 csvData ; pcolor
    set csvData lput -1 csvData ; conflict name
    set csvData lput -1 csvData ; with (1) /without (2) competences
    set csvData lput -1 csvData ; competence level1
    set csvData lput -1 csvData ; competence level2
    set csvData lput -1 csvData ; competence average
    set csvData lput -1 csvData ; tki
    set csvData lput -1 csvData ; solution
    set csvData lput -1 csvData ; solution competenceLevel

    file-open "agentsEvaluatedMoreThan3.csv"
    file-print csv:to-row (csvData)
    file-close
    set countRowsCsv countRowsCsv + 1
    set csvData[]
  ]

  if (allLevels != 0) [ set competenceLevel mean allLevels ]





  set turtlesToEvaluate 0


end

to set-competence-agent [agent color1]
  let competence get-competence-conflict color1
  if (individualCompetences = 0) [
    set individualCompetences []
  ]
    let competenceExists false
    foreach individualCompetences [
      i ->
      if (item 0 i = competence) [
        set competenceExists true
      ]
    ]
    if (competenceExists = false) [
      let randomValue (1 + random (11 - 1))
      set individualCompetences lput (list competence randomValue) individualCompetences

    ]

end

to evaluate-agents [agents]





  let posColor 2
  let counter 0
  if (agents != 0) [
    let agentCompetenceValues []
    foreach agents [
      i ->


      ifelse (counter < posColor) [

        let conflictCompetence get-competence-conflict item posColor agents
        set agentCompetenceValues lput (list (get-competence-value-agent conflictCompetence) (item counter agents) (conflictCompetence)) agentCompetenceValues
      ][
        set csvData lput countRowsCsv csvData; Row Number (name in R)
        set csvData lput ticksNumber csvData ; ticks number
        set csvData lput ticks csvData ; current tick
        let x [pxcor] of turtle item 1 item 0 agentCompetenceValues
        let y [pycor] of turtle item 1 item 0 agentCompetenceValues
        let zone "empty";
        if ((x >= 0 and x <= 20) and (y > 20  and y <= 40)) [
          set zone "Work"
        ]
        if ((x >= 0 and x <= 20) and (y >= 0  and y <= 20)) [
          set zone "Home"
        ]
        if ((x >= 20 and x <= 40) and (y >= 0 and y <= 20)) [
          set zone "Street"
        ]
        if ((x > 20 and x <= 40) and (y > 20  and y <= 40)) [
          set zone "SocialMarketing"
        ]
        set csvData lput zone csvData ; zone
        let solution false
        ifelse (withCompetences = true) [
          set solution solving-conflict-with-competences agentCompetenceValues
          sum-solution-zone solution item 1 item 0 agentCompetenceValues
        ][
          set solution solving-conflict-randomly agentCompetenceValues
          sum-solution-zone solution item (counter - 1) agents
        ]

        ifelse (competenceLevel = 0 ) [
          ;; Data to export
          set csvData lput -1 csvData
        ][
          set csvData lput competenceLevel csvData
        ]

        set avoiding 0
        set competing 0
        set accommodating 0
        set collaborating 0
        set compromising 0

        set agentCompetenceValues []
        set posColor posColor + 3
        ifelse (withCompetences = true )[
          file-open "agentsEvaluatedWithCompetences.csv"
          file-print csv:to-row (csvData)
          file-close
        ][
          file-open "agentsEvaluatedRandomly.csv"
          file-print csv:to-row (csvData)
          file-close
        ]
        set countRowsCsv countRowsCsv + 1
        set csvData[]
      ]
      set counter counter + 1


    ]
  ]
end

to-report get-competence-conflict [colorConflict]
  let competence "empty"
  foreach conflictsList[
    i ->
    if (colorConflict = item 2 i) [
      set competence item 3 i
    ]
  ]
  report competence
end

to-report get-conflict-name [colorConflict]
  let conflict "empty"
  foreach conflictsList [
    i ->
    if (item 2 i = colorConflict) [
      set conflict item 0 i
    ]
  ]
  report conflict
end

to-report get-competence-value-agent [competence]
  let competenceValue -1
  ask turtles [
    if (individualCompetences != 0) [
      foreach individualCompetences [
        i ->
        if (item 0 i = competence) [
          set competenceValue item 1 i
        ]
      ]
    ]
  ]
  report competenceValue
end

to-report agentExists [agent]
  let exists false
  if (turtlesToEvaluate != 0)
  [
    let counter 0
    let colorPos 2
    foreach turtlesToEvaluate
    [
      i ->
      ifelse (counter < colorPos) [
        if (i = agent) [
          set exists true
        ]
      ][
        set colorPos colorPos + 3
      ]
      set counter counter + 1
    ]
  ]

  report exists
end

to-report existsConflict [patchColor]
  let exists false
  foreach conflictsList
  [
    i ->
    if(item 2 i = patchColor)[
      set exists true
    ]
  ]
  report exists
end

to-report solving-conflict-with-competences [levels]
  let solution false
  let agent 0
  let agentUp 0

  ;; Data to export
  set csvData lput (item 1 item 0 levels) csvData ;; agent 1
  set csvData lput (item 1 item 1 levels) csvData ;; agent 1
  let color1 [pcolor] of turtle (item 1 item 0 levels)
  set csvData lput color1 csvData ;; patch color
  set csvData lput (get-conflict-name color1) csvData  ;; conflict name
  set csvData lput 1 csvData ;; with competences




  ifelse (item 0 item 0 levels >= 5 or item 0 item 1 levels >= 5 ) [

      let tkiNumber tki

      ;; Data to export
      set csvData lput tkiNumber csvData

      ;; avoiding
      if (tkiNumber = 1) [
      ifelse (item 0 item 0 levels >= 8 and item 0 item 1 levels >= 8 ) [
      set solved solved + 1
        set solution true
      set agent 1 ; both agents + 0.5
    ][ ; ELSE if competence level >= 8
        set notSolved notSolved + 1
      ]
      ]
      ;; competing
      if (tkiNumber = 2) [
        let index 0
        let randomNumber (0 + random (2 - 0))
        let win false
        ifelse (randomNumber = 1 )[
          set index randomNumber
          if ( item 0 item 1 levels > item 0 item 0 levels)[
            set win true
            set agent item 1 item 1 levels ; this agent + 1
            set agentUp 1
          ]
        ][
          if ( item 0 item 0 levels > item 0 item 1 levels)[
            set win true
            set agent item 1 item 0 levels ; this agent + 1
            set agentUp 2
          ]
        ]

        ifelse (win = true) [
          set solved solved + 1
          set solution true
        ][
          set notSolved notSolved + 1
        ]
      ]
      ;; accommodating or compromising
      if (tkiNumber = 3) [
        set solved solved + 1
        set solution true
        set agent 2 ; both agents + 1
      ]
      ;; collaborating
      if (tkiNumber = 4)[
        ifelse (item 0 item 0 levels >= 5 and item 0 item 1 levels >= 5)[
          set solved solved + 1
          set solution true
          set agent 2 ; both agents + 1
        ][
          set notSolved notSolved + 1
        ]
      ]
    ; compromising
      if (tkiNumber = 5) [
      ifelse ((item 0 item 0 levels >= 3 and item 0 item 0 levels <= 6) and (item 0 item 1 levels >= 3 and item 0 item 1 levels <= 6))[
        set solved solved + 1
        set solution true
        set agent 2 ; both agents + 1
      ][
        ifelse (item 0 item 0 levels >= 8 or item 0 item 1 levels >= 8 ) [
          set solved solved + 1
          set solution true
          set agent 2 ; both agents + 1
        ][
          set notSolved notSolved + 1
        ]
      ];ELSE
      ]

  ][;ELSE
    set notSolved notSolved + 1
    ;; Data to export
    set csvData lput -1 csvData ;; instead of tki
  ]

  if (agent = 1) [
    increase-competence-level (item 1 item 0 levels) (item 2 item 0 levels) 0.5
    increase-competence-level (item 1 item 1 levels) (item 2 item 0 levels) 0.5
    set csvData lput ((item 0 item 0 levels) + 0.5) csvData ;; competence level 1
    set csvData lput ((item 0 item 1 levels) + 0.5) csvData ;; competence level 2
    let average mean (list ((item 0 item 0 levels) + 0.5) ((item 0 item 1 levels) + 0.5))
    set csvData lput average csvData ;; average
  ]
  if (agent = 2) [
    increase-competence-level (item 1 item 0 levels) (item 2 item 0 levels) 1
    increase-competence-level (item 1 item 1 levels) (item 2 item 0 levels) 1
    set csvData lput ((item 0 item 0 levels) + 1) csvData ;; competence level 1
    set csvData lput ((item 0 item 1 levels) + 1) csvData ;; competence level 2
    let average mean (list ((item 0 item 0 levels) + 1) ((item 0 item 1 levels) + 1))
    set csvData lput average csvData ;; average
  ]
  if (agent != 0 and agent != 1 and agent != 2) [
    increase-competence-level (agent) (item 2 item 0 levels) 1
    ifelse (agentUp = 1) [
      set csvData lput ((item 0 item 0 levels) + 1) csvData ;; competence level 1
      set csvData lput (item 0 item 1 levels) csvData ;; competence level 2
      let average mean (list ((item 0 item 0 levels) + 1) ((item 0 item 1 levels)))
      set csvData lput average csvData ;; average
    ][
      set csvData lput (item 0 item 0 levels) csvData ;; competence level 1
      set csvData lput ((item 0 item 1 levels) + 1) csvData ;; competence level 2
      let average mean (list ((item 0 item 0 levels)) ((item 0 item 1 levels) + 1))
      set csvData lput average csvData ;; average
    ]

  ]



  ;; Data to export
  set csvData lput solution csvData
  report solution
end

to increase-competence-level [agent competence plusValue]
  if ([individualCompetences] of turtle agent != 0) [
    let counter 0
    ask turtle agent [
      foreach individualCompetences [
        i ->
        if (item 0 i = competence) [
          let newValue (item 1 i + plusValue)
          if (newValue <= 10 ) [
            set individualCompetences replace-item counter individualCompetences replace-item 1 i newValue
            if (allLevels = 0)
            [set allLevels []

            ]
            set allLevels lput newValue allLevels
          ]
        ]
        set counter counter +  1
      ]
    ]

  ]
end

to-report solving-conflict-randomly [levels]
  let solution false

  ;; Data to export
  set csvData lput (item 1 item 0 levels) csvData ;; agent 1
  set csvData lput (item 1 item 1 levels) csvData ;; agent 1
  let color1 [pcolor] of turtle (item 1 item 0 levels)
  set csvData lput color1 csvData ;; patch color
  set csvData lput (get-conflict-name color1) csvData  ;; conflict name
  set csvData lput 2 csvData ;; randomly without competences
  set csvData lput (item 0 item 0 levels) csvData ;; competence level 1
  set csvData lput (item 0 item 1 levels) csvData ;; competence level 2
  let average mean (list (item 0 item 0 levels) (item 0 item 1 levels))
  set csvData lput average csvData ;; average


  let tkiNumber tki

  ;;Data to export
  set csvData lput tkiNumber csvData

  ;; avoiding
  if (tkiNumber = 1) [
    set notSolved notSolved + 1
  ]
  ;; competing
  if (tkiNumber = 2) [
    ifelse((1 + random (3 - 1)) = 2) [
      set solved solved + 1
      set solution true
    ][
      set notSolved notSolved + 1
    ]
  ]
  ;; accommodating
  if (tkiNumber = 3) [
    let random1 (1 + random (11 - 1))
      let random2 (1 + random (11 - 1))
    let whois (1 + random (3 - 1))
    ifelse (whois = 1)[
        ifelse(random1 > random2) [
          set solved solved + 1
          set solution true
        ][
          set notSolved notSolved + 1
        ]
    ][
      ifelse(random2 > random1) [
          set solved solved + 1
          set solution true
        ][
          set notSolved notSolved + 1
        ]
    ]
  ]



  ;; collaborating
  if (tkiNumber = 4)[
    let random1 (1 + random (3 - 1))
      let random2 (1 + random (3 - 1))
        ifelse(random1 = 2 and random2 = 2) [
          set solved solved + 1
          set solution true
        ][
          set notSolved notSolved + 1
        ]
  ]

  ;; compromising
  if (tkiNumber = 5) [
    let random1 (1 + random (11 - 1))
    ifelse (random1 >= 3 and random1 <= 6) [
      set solved solved + 1
      set solution true
    ][
      set notSolved notSolved + 1
    ]

  ]

  ;; Data to export
  set csvData lput solution csvData

  report solution
end

to-report tki
  let tkiSelect one-of ["avoiding" "competing" "accommodating" "collaborating" "compromising"]
  let tkiNumber 0
  if (tkiSelect = "avoiding")[
    set avoiding 1
    set tkiNumber 1
  ]
  if (tkiSelect = "competing")[
    set competing 1
    set tkiNumber 2
  ]
  if (tkiSelect = "accommodating")[
    set accommodating 1
    set tkiNumber 3
  ]
  if (tkiSelect = "collaborating")[
    set collaborating 1
    set tkiNumber 4
  ]
  if (tkiSelect = "compromising")[
    set compromising 1
    set tkiNumber 5
  ]

  report tkiNumber
end

to sum-solution-zone [solution agent]

  let x [pxcor] of turtle agent
  let y [pycor] of turtle agent
  if ((x >= 0 and x <= 20) and (y > 20  and y <= 40)) [
    ;;Work
    set peopleAtWork peopleAtWork + 1
    ifelse (solution = true ) [
      set confSolWork confSolWork + 1
      set totalConfSolWork totalConfSolWork + 1
    ][
      set totalConfSolWork totalConfSolWork + 1
    ]
  ]

  if ((x >= 0 and x <= 20) and (y >= 0 and y <= 20)) [
    ;;Home
    set peopleAtHome peopleAtHome + 1
    ifelse (solution = true ) [
      set confSolHome confSolHome + 1
      set totalConfSolHome totalConfSolHome + 1
    ][
      set totalConfSolHome totalConfSolHome + 1
    ]
  ]

  if ((x >= 20 and x <= 40) and (y >= 0 and y <= 20)) [
    ;;Street
    set peopleAtStreet peopleAtStreet + 1
    ifelse (solution = true ) [
      set confSolStreet confSolStreet + 1
      set totalConfSolStreet totalConfSolStreet + 1
    ][
      set totalConfSolStreet totalConfSolStreet + 1
    ]
  ]

  if ((x > 20 and x <= 40) and (y > 20 and y <= 40)) [
    ;;SocialM
    set peopleAtSocialMarketing peopleAtSocialMarketing + 1
    ifelse (solution = true ) [
      set confSolSocialM confSolSocialM + 1
      set totalConfSolSocialM totalConfSolSocialM + 1
    ][
      set totalConfSolSocialM totalConfSolSocialM + 1
    ]
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
5
52
424
472
-1
-1
10.0244
1
10
1
1
1
0
1
1
1
0
40
0
40
0
0
1
ticks
30.0

SLIDER
509
45
687
78
numberOfCitizens
numberOfCitizens
10
500
200.0
1
1
NIL
HORIZONTAL

BUTTON
506
109
570
142
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
85
36
138
54
WORK
12
62.0
1

TEXTBOX
88
480
118
498
HOME
11
135.0
1

TEXTBOX
310
480
350
498
STREET
11
85.0
1

TEXTBOX
256
34
355
52
SOCIAL MARKETING\n
11
115.0
1

TEXTBOX
18
10
416
28
CITIZENSHIP COMPETENCES SIMULATION
18
0.0
1

PLOT
787
328
1104
483
Presence of people
Time
Citizens
0.0
150.0
0.0
10.0
true
true
"" "ifelse (ticks = 0)[\nset-plot-x-range 0 1\n][\nset-plot-x-range 0 ticks\n]"
PENS
"Work" 1.0 0 -10899396 true "" "plot peopleAtWork"
"Home" 1.0 0 -5825686 true "" "plot peopleAtHome"
"Street" 1.0 0 -11221820 true "" "plot peopleAtStreet"
"Social Marketing" 1.0 0 -8630108 true "" "plot peopleAtSocialMarketing"

BUTTON
574
109
637
142
Go
repeat ticksNumber [go]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
642
109
715
142
Restart
restart
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
570
20
634
42
Citizens
18
0.0
1

TEXTBOX
529
225
699
248
Conflict's interactions
18
0.0
1

TEXTBOX
532
252
570
270
Work
13
0.0
1

TEXTBOX
530
317
569
335
Home
13
0.0
1

TEXTBOX
672
319
714
337
Street
13
0.0
1

TEXTBOX
644
251
755
269
Social Marketing
13
0.0
1

MONITOR
489
270
546
315
Solved
confSolWork
17
1
11

MONITOR
546
270
603
315
Total
totalConfSolWork
17
1
11

MONITOR
488
335
545
380
Solved
confSolHome
17
1
11

MONITOR
635
335
692
380
Solved
confSolStreet
17
1
11

MONITOR
630
269
687
314
Solved
confSolSocialM
17
1
11

MONITOR
545
335
602
380
Total
totalConfSolHome
17
1
11

MONITOR
690
335
747
380
Total
totalConfSolStreet
17
1
11

MONITOR
687
269
744
314
Total
totalConfSolSocialM
17
1
11

TEXTBOX
575
84
637
106
Options
18
0.0
1

PLOT
786
172
1103
322
Competences level
Time
Level
0.0
100.0
0.0
10.0
true
false
"" "ifelse (ticks = 0)[\nset-plot-x-range 0 1\n][\nset-plot-x-range 0 ticks\n]"
PENS
"default" 1.0 0 -16777216 true "" "plot competenceLevel"

PLOT
785
13
1101
163
Conflicts solved vs not solved
Time
Conflicts
0.0
150.0
0.0
10.0
true
false
"" "ifelse (ticks = 0)[\nset-plot-x-range 0 1\n][\nset-plot-x-range 0 ticks\n]"
PENS
"Solved" 1.0 0 -10899396 true "" "plot solved"
"Not solved" 1.0 0 -2674135 true "" "plot notSolved"

SWITCH
506
150
647
183
withCompetences
withCompetences
0
1
-1000

INPUTBOX
653
149
703
209
ticksNumber
100.0
1
0
Number

@#$#@#$#@
## WHAT IS IT?

The purpose of the ABSSCC (Agent Based Social Simulation for Citizenship Competences) model is to understand how citizenship competences influence in the conflicts’ resolution. In this model people interact in zones where they should solve conflicts and a conflict is solved considering two cases: when there is the presence of citizenship competences and when not. In both cases the solution of a conflict depends also on the TKI level which is selected randomly. The simulation was designed taking into account the citizenship competences model proposed by (Chaux et al., 2004) and the TKI conflict resolution styles (Thomas & Kilmann, 1974, 2008). The competences model was implemented into an RDF (Resource Description Framework) ontology. A NetLogo extension was developed in order to retrieve information from the ontology. Each conflict has associated a competence and the information about the conflicts and their competences is retrieved from an ontology which was developed in Protégé. To do so, a NetLogo extension was developed using the Java programming language and the JENA API (to make queries over the ontology).

## HOW IT WORKS

The model has only one type of breed (citizens). The simulation scenario consists of four zones: work, home, street, and a social marketing area which refers to those places with advertisements or information about things like taking care of a place or throwing litter in the right place, among others. 

The scenario should have at least two people so that they can interact in the resolution of conflicts in each zone. In addition, a competence is associated with each conflict and each time two people interact in the resolution of a conflict, the level of competencies for each citizen is specified. Initially, this level is defined randomly and then is updated each time the citizen interacts in a new conflict. In the simulation there is a switch that allows to determine if the simulation will run considering OR not the citizenship competences. When that switch is off, conflicts are solved in a random manner otherwise, a conflict is solved taking into account the level of competence of each of the citizens who interact in that conflict. 

The simulation space, which in NetLogo is known as the “world”, is a space with a total of 1600 plots divided into a 40 by 40 frame. The origin is settled in the left-down. This world in turn is divided by 4 zones of equal size, each zone is identified with a different color and represents the zones mentioned above. Within each of these zones, a maximum of 10 conflicts are defined, each conflict is represented in the world by a set of 9 patches. Each unit in time is represented by a tick which is in turn each step that is performed in the system. 
 
The scenario also includes a set of variables that allow to store information about the simulation through the time (ticks) and that are also used to store the information in a comma separated file by using the csv extension.
One of the variables defined for the scenario is a scale by which you can configure the number of citizens that will be added to the simulation space. This scale ranges from 10 to 500. There is also a parameter that allows defining the amount of ticks that the simulation will last. 

Regarding the output information, there are information boxes that show the conflicts that have been solved and the total conflicts in which each area has been interacted. In addition, three graphs are presented, one that allows the comparison of solved conflicts versus not-solved conflicts over time, a second graph that represents the behavior of the general competence level of the simulation system and a final graph that represents the presence of people for each of the zones.


## HOW TO USE IT

1. Move the numberOfCitizens slider to select the number of initial citizens.
2. Switch on / off the withCompetences switch in order to decide if the simulation should consider the citizenship competences or not.
3. Use the Setup button in order to set the initial values.
4. Use the Go button in order to start the simulation. The simulation will run until 150 ticks (the variable generalCounts can be updated to change the number of ticks).
5. Use the Restart button in order to set default values, clean the escenario and the plots.

* The Conflicts solved vs not solved plot shows the number of conflicts solved and not solved during the simulation.
* The Competences level shows 


## THINGS TO NOTICE
When the withCompetences switch is off, the competences level plot does not change the current value of the level of competence (by default zero).

## THINGS TO TRY

The numberOfCitizens slider can be moved in order to vary the number of citizens in the escenario.

The withCompetences switch can be changed in order to observe differences in the results if the citizenship competences are considered or not.


## NETLOGO FEATURES
* This model was developed using NetLogo 6.1.1
* This model uses a NetLogo extension, developed by the autors.This extension makes queries over an ontology and to do it uses the JENA library and the ontology (also developed for this simulation). The extension was developed in the Java programming language.
* The ontology represents the citizenship competences according to the colombian model and it was developed in Protégé 5.5.

## CREDITS AND REFERENCES

This simulation was developed by: 

Cecilia Avila from the Faculty of Mathematics and Engineering at the Fundación Universitaria Konrad Lorenz (Bogotá, Colombia)

Manuel Balaguera from the Business School at the Fundación Universitaria Konrad Lorenz (Bogotá, Colombia)

Valentina Tabares from the Faculty of Engineering at the Universidad Nacional de Colombia (Manizalez, Colombia)

Corresponding author: 
* cecilia.avilag@konradlorenz.edu.co
* ceciliaagarzon@gmail.com

Dec 30, 2019
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
